/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;

import org.gnu.glib.Boxed;
import org.gnu.glib.Handle;

public class PixbufAnimationIter extends Boxed 
{
    
    /****************************************
     * BEGINNING OF JNI CODE
     ****************************************/
    native static final protected int gdk_pixbuf_animation_iter_get_type ();
    native static final protected int gdk_pixbuf_animation_iter_get_delay_time (Handle iter);
    native static final protected Handle gdk_pixbuf_animation_iter_get_pixbuf (Handle iter);
    native static final protected boolean gdk_pixbuf_animation_iter_on_currently_loading_frame (Handle iter);
    /****************************************
     * END OF JNI CODE
     ****************************************/
}

